@@ -5,3 +5,5 @@
 ; copy pack
 (tl-load "copy")
 (compile-file "copy.lisp")
+; Clisp integration module
+(ext:without-package-lock ("SYSTEM") (tl-load "clisp-pluggin") (compile-file "clisp-pluggin.lisp"))
