@@ -32,4 +32,5 @@
 (cl:let ((loadPaths (cl:list ; TL's core methods, funcs, etc.
  "tl-sys:core;other-macs" "tl-sys:core;container-types-and-macs" "tl-sys:core;oper-macs" "tl-sys:core;other-funcs" "tl-sys:core;oper-meths" "tl-sys:core;other-meths" "tl-sys:core;container-meths" ; TL's translator
  "tl-sys:core;transl-const" "tl-sys:core;transl-string-reading" "tl-sys:core;transl-elem-search-funcs" "tl-sys:core;transl-form-building" "tl-sys:core;transl-form-writting" ; TL's loading func
- "tl-sys:core;loader-funcs"))) (dolist (logPath loadPaths) (cl:load (logical-pathname logPath))))
+ "tl-sys:core;loader-funcs" ; reader macro for Clisp to read TL code
+ "tl-sys:core;reader-tl-macro"))) (dolist (logPath loadPaths) (cl:load (logical-pathname logPath))))
